==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new PercentagePriceOscillatorIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return PercentagePriceOscillatorIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.uq));
        }
        set shortPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.uq, a);
        }
        uc() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.up));
        }
        set longPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.up, a);
        }
        t9() {
            return this.longPeriod;
        }
    }
    PercentagePriceOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.uo(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.up = /*@__PURE__*/ StrategyBasedIndicator.uk(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
})();

==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new PercentagePriceOscillatorIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return PercentagePriceOscillatorIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.u3));
        }
        set shortPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.u3, a);
        }
        up() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.u2));
        }
        set longPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.u2, a);
        }
        um() {
            return this.longPeriod;
        }
    }
    PercentagePriceOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.u1(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.u2 = /*@__PURE__*/ StrategyBasedIndicator.ux(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
})();
